@@ -76,13 +76,18 @@ void KimpanelInputPanel::updateLocation()
     x = qMax(x, screenRect.x());
     int oy = m_spotRect.y() + m_spotRect.height();
     int y = oy + 10;
+    if (y < screenRect.y()) {
+        y = screenRect.y();
+    }
+
     if (y > screenRect.y() + screenRect.height()) {
-        y = screenRect.height();
+        y = oy = screenRect.y() + screenRect.height();
     }
 
     if (y + height() > screenRect.y() + screenRect.height()) {
         /// minus 20 to make preedit bar never overlap the input context
         y = oy - (height() + ((m_spotRect.height() == 0)?20:(m_spotRect.height() + 10)));
+
         m_widget->setReverse(true);
     }
     else
